@@ -12,14 +12,15 @@ namespace Tomboy
 	{
 		static NoteManager manager;
 		static TomboyTrayIcon tray_icon;
-		static TomboyTray tomboy_tray = null;
+		static TomboyTray tray = null;
 		static bool tray_icon_showing = false;
 		static bool is_panel_applet = false;
 		static PreferencesDialog prefs_dlg;
 		static SyncDialog sync_dlg;
-		#if ENABLE_DBUS
+#if ENABLE_DBUS
 		static RemoteControl remote_control;
-		#endif
+#endif
+		static Gtk.IconTheme icon_theme = null;
 
 		public static void Main (string [] args)
 		{
@@ -28,16 +29,20 @@ namespace Tomboy
 
 			TomboyCommandLine cmd_line = new TomboyCommandLine (args);
 
-			#if ENABLE_DBUS // Run command-line earlier with DBus enabled
+#if ENABLE_DBUS // Run command-line earlier with DBus enabled
 			if (cmd_line.NeedsExecute) {
 				// Execute args at an existing tomboy instance...
 				cmd_line.Execute ();
 				return;
 			}
-			#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS
 
 			Initialize ("tomboy", "Tomboy", "tomboy", args);
 
+			// Add private icon dir to search path
+			icon_theme = Gtk.IconTheme.Default;
+			icon_theme.AppendSearchPath (System.IO.Path.Combine (Defines.DATADIR, "tomboy/icons"));
+
 //   PluginManager.CheckPluginUnloading = cmd_line.CheckPluginUnloading;
 
 			// Create the default note manager instance.
@@ -58,11 +63,11 @@ namespace Tomboy
 				addin.Initialize ();
 			}
 
-			#if !ENABLE_DBUS
+#if !ENABLE_DBUS
 			if (cmd_line.NeedsExecute) {
 				cmd_line.Execute ();
 			}
-			#endif
+#endif
 
 			if (cmd_line.UsePanelApplet) {
 				tray_icon_showing = true;
@@ -87,8 +92,7 @@ namespace Tomboy
 		static string GetNotePath (string override_path)
 		{
 			// Default note location, as specified in --note-path or $TOMBOY_PATH
-			string note_path =
-			        (override_path != null) ?
+			string note_path = (override_path != null) ?
 			        override_path :
 			        Environment.GetEnvironmentVariable ("TOMBOY_PATH");
 			if (note_path == null)
@@ -108,40 +112,35 @@ namespace Tomboy
 		static void StartTrayIcon ()
 		{
 			// Create the tray icon and run the main loop
-			tray_icon = new TomboyTrayIcon (DefaultNoteManager);
+			tray_icon = new TomboyTrayIcon (manager);
+			tray = tray_icon.Tray;
 
 			// Give the TrayIcon 2 seconds to appear.  If it
 			// doesn't by then, open the SearchAllNotes window.
-			tray_icon.Embedded += TrayIconEmbedded;
-			GLib.Timeout.Add (2000, CheckTrayIconShowing);
-			tray_icon.Show ();
+			tray_icon_showing = tray_icon.IsEmbedded && tray_icon.Visible;
+			if (!tray_icon_showing)
+				GLib.Timeout.Add (2000, CheckTrayIconShowing);
 
 			StartMainLoop ();
 		}
 
-		// This event is signaled when Tomboy's TrayIcon is added to the
-		// Notification Area.  If it's never signaled, the Notification Area
-		// is not available.
-		static void TrayIconEmbedded (object sender, EventArgs args)
-		{
-			tray_icon_showing = true;
-		}
-
 		static bool CheckTrayIconShowing ()
 		{
+			tray_icon_showing = tray_icon.IsEmbedded && tray_icon.Visible;
+			
 			// Check to make sure the tray icon is showing.  If it's not,
 			// it's likely that the Notification Area isn't available.  So
 			// instead, launch the Search All Notes window so the user can
 			// can still use Tomboy.
 			if (tray_icon_showing == false)
 				ActionManager ["ShowSearchAllNotesAction"].Activate ();
-
+			
 			return false; // prevent GLib.Timeout from calling this method again
 		}
 
 		static void RegisterRemoteControl (NoteManager manager)
 		{
-			#if ENABLE_DBUS
+#if ENABLE_DBUS
 			try {
 				remote_control = RemoteControlProxy.Register (manager);
 				if (remote_control != null) {
@@ -163,7 +162,7 @@ namespace Tomboy
 				Logger.Log ("Tomboy remote control disabled (DBus exception): {0}",
 				            e.Message);
 			}
-			#endif
+#endif
 		}
 
 		// These actions can be called from anywhere in Tomboy
@@ -241,10 +240,10 @@ namespace Tomboy
 
 		static void OnShowHelpAction (object sender, EventArgs args)
 		{
-			// Pass in null for the screen when we're running as a panel applet
 			GuiUtils.ShowHelp("tomboy.xml", null,
-			                  tray_icon == null ? null : tray_icon.TomboyTray.Screen,
+			                  tray_icon == null ? null : tray_icon.Screen,
 			                  null);
+
 		}
 
 		static void OnShowAboutAction (object sender, EventArgs args)
@@ -257,11 +256,16 @@ namespace Tomboy
 				"Ryan Lortie <desrt@desrt.ca>",
 				"Sandy Armstrong <sanfordarmstrong@gmail.com>",
 				"Sebastian Rittau <srittau@jroger.in-berlin.de>",
-				"Kevin Kubasik <kevin@kubasik.net>"
+				"Kevin Kubasik <kevin@kubasik.net>",
+				"Stefan Schweizer <steve.schweizer@gmail.com>"
 			};
 
 			string [] documenters = new string [] {
-				"Alex Graveley <alex@beatniksoftware.com>"
+				"Alex Graveley <alex@beatniksoftware.com>",
+				"Boyd Timothy <btimothy@gmail.com>",
+				"Brent Smith <gnome@nextreality.net>",
+				"Paul Cutler <pcutler@foresightlinux.org>",
+				"Sandy Armstrong <sanfordarmstrong@gmail.com>"
 			};
 
 			string translators = Catalog.GetString ("translator-credits");
@@ -315,13 +319,9 @@ namespace Tomboy
 		public static TomboyTray Tray
 		{
 			get {
-				if (tray_icon != null)
-					return tray_icon.TomboyTray;
-				else
-					return tomboy_tray;
-			}
-			set {
-				tomboy_tray = value;
+				return tray;
+			} set {
+				tray = value;
 			}
 		}
 
@@ -408,7 +408,7 @@ namespace Tomboy
 			                "  --search [text]\t\tOpen the search all notes window with " +
 			                "the search text.\n");
 
-			#if ENABLE_DBUS
+#if ENABLE_DBUS
 			usage +=
 			        Catalog.GetString (
 			                "  --new-note\t\t\tCreate and display a new note.\n" +
@@ -419,7 +419,7 @@ namespace Tomboy
 			                "  --start-here\t\t\tDisplay the 'Start Here' note.\n" +
 			                "  --highlight-search [text]\tSearch and highlight text " +
 			                "in the opened note.\n");
-			#endif
+#endif
 
 // TODO: Restore this functionality with addins
 //   usage +=
@@ -427,9 +427,9 @@ namespace Tomboy
 //     "  --check-plugin-unloading\tCheck if plugins are " +
 //     "unloaded properly.\n");
 
-			#if !ENABLE_DBUS
+#if !ENABLE_DBUS
 			usage += Catalog.GetString ("D-BUS remote control disabled.\n");
-			#endif
+#endif
 
 			Console.WriteLine (usage);
 		}
@@ -445,7 +445,7 @@ namespace Tomboy
 				bool quit = false;
 
 				switch (args [idx]) {
-					#if ENABLE_DBUS
+#if ENABLE_DBUS
 				case "--new-note":
 					// Get optional name for new note...
 					if (idx + 1 < args.Length
@@ -499,7 +499,7 @@ namespace Tomboy
 					++idx;
 					highlight_search = args [idx];
 					break;
-					#else
+#else
 				case "--new-note":
 				case "--open-note":
 				case "--start-here":
@@ -513,7 +513,7 @@ namespace Tomboy
 					Console.WriteLine (unknown_opt, args [idx]);
 					quit = true;
 					break;
-					#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS
 
 				case "--panel-applet":
 					panel_applet = true;
@@ -580,7 +580,7 @@ namespace Tomboy
 
 		public void Execute ()
 		{
-			#if ENABLE_DBUS
+#if ENABLE_DBUS
 			RemoteControl remote = null;
 			try {
 				remote = RemoteControlProxy.GetInstance ();
@@ -673,7 +673,7 @@ namespace Tomboy
 				else
 					remote.DisplaySearch ();
 			}
-			#else
+#else
 			if (open_search) {
 				NoteRecentChanges recent_changes =
 				        NoteRecentChanges.GetInstance (Tomboy.DefaultNoteManager);
@@ -685,7 +685,7 @@ namespace Tomboy
 
 				recent_changes.Present ();
 			}
-			#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS
 		}
 	}
 }
